==================================================
``psyclone.psyir.transformations.loop_swap_trans``
==================================================

.. automodule:: psyclone.psyir.transformations.loop_swap_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.loop_swap_trans


Classes
=======

- :py:class:`LoopSwapTrans`:
  Provides a loop-swap transformation, e.g.:


.. autoclass:: LoopSwapTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: LoopSwapTrans
      :parts: 1
